import logging
import os

from fastapi import FastAPI, Request

from .snakes.snake import Snake
from . import api


snake_name = os.getenv("SNAKE")

if snake_name is None:
    print("SNAKE env variable is not set!")
    exit(1)

snake = Snake.SNAKES[snake_name]()

app = FastAPI(title=snake.name,
              summary=f"API for {snake.name}")

@app.get("/")
def on_info() -> api.GetResponse:
    print("INFO")
    return snake.info()

@app.post("/start")
def on_start(request: api.StartRequest) -> api.StartResponse:
    return snake.start(request)

@app.post("/move")
def on_move(request: api.MoveRequest) -> api.MoveResponse:
    return snake.move(request)

@app.post("/end")
def on_end(request: api.EndRequest) -> api.EndResponse:
    return snake.end(request)


@app.middleware("http")
async def identify_server(request: Request, call_next):
    response = await call_next(request)
    response.headers["server"] = "shillerben/gitea/starter-snake-python"
    return response

logging.getLogger("werkzeug").setLevel(logging.ERROR)
